// import * as React from 'react'
import { experimentalStyled as styled, alpha } from '@mui/material/styles'
import AppBar from '@mui/material/AppBar'
import Box from '@mui/material/Box'
import Toolbar from '@mui/material/Toolbar'
import Typography from '@mui/material/Typography'
import InputBase from '@mui/material/InputBase'
import SearchIcon from '@mui/icons-material/Search'
import Paper from '@mui/material/Paper'
import Grid from '@mui/material/Grid'
import Avatar from '@mui/material/Avatar'
import IconButton from '@mui/material/IconButton'
import DarkModeOutlined from '@mui/icons-material/DarkModeOutlined'
import LightModeOutlined from '@mui/icons-material/LightModeOutlined'
import { ColorModeContext } from '@contexts'
import React, { useContext } from 'react'
import { useRouter } from 'next/router'
import FormControl from '@mui/material/FormControl'
import MenuItem from '@mui/material/MenuItem'
import Select from '@mui/material/Select'
import Stack from '@mui/material/Stack'
import Link from 'next/link'

const info = ('This is the FDO Manager. The hardware and infrastructure for this test instance are provided by GWDG. IndiScale is responsible for the architecture and implementation.')

const Item = styled(Paper)(({ theme }) => ({
  backgroundColor: theme.palette.mode === 'dark' ? '#1A2027' : '#fff',
  ...theme.typography.body2,
  padding: theme.spacing(2),
  textAlign: 'center',
  color: theme.palette.text.secondary
}))

const Search = styled('div')(({ theme }) => ({
  position: 'relative',
  borderRadius: theme.shape.borderRadius,
  backgroundColor: alpha(theme.palette.common.white, 0.15),
  '&:hover': {
    backgroundColor: alpha(theme.palette.common.white, 0.25)
  },
  marginLeft: 0,
  width: '100%',
  [theme.breakpoints.up('sm')]: {
    marginLeft: theme.spacing(1),
    width: '250px'
  }
}))

const SearchIconWrapper = styled('div')(({ theme }) => ({
  padding: theme.spacing(0, 2),
  height: '100%',
  position: 'absolute',
  pointerEvents: 'none',
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'center'
}))

const StyledInputBase = styled(InputBase)(({ theme }) => ({
  color: 'inherit',
  width: '100%',
  '& .MuiInputBase-input': {
    padding: theme.spacing(1, 1, 1, 0),
    // vertical padding + font size from searchIcon
    paddingLeft: `calc(1em + ${theme.spacing(4)})`,
    transition: theme.transitions.create('width'),
    [theme.breakpoints.up('sm')]: {
      width: '12ch',
      '&:focus': {
        width: '20ch'
      }
    }
  }
}))

export default function Index () {
  const { mode, setMode } = useContext(ColorModeContext)
  const { locale: currentLocale, locales, pathname, query } = useRouter()

  return (
    <Box sx={{ flexGrow: 1 }}>
      <AppBar position="static">
        <Toolbar>
         <Avatar src="images/logo-fdo-img.png"></Avatar>
          <Typography
            variant="h6"
            noWrap
            component="div"
            marginLeft={2}
            sx={{ flexGrow: 1, display: { xs: 'none', sm: 'block' } }}
          >
            FDO MANAGER
          </Typography>

          <Search>
            <SearchIconWrapper>
              <SearchIcon />
            </SearchIconWrapper>
            <StyledInputBase
              placeholder="Search…"
              inputProps={{ 'aria-label': 'search' }}
            />
          </Search>
          <Stack marginLeft={3}>
          <FormControl sx={{ minWidth: 64 }}>
              <Select
                disableUnderline
                defaultValue={currentLocale}
                inputProps={{ 'aria-label': 'Without label' }}
                variant="standard"
                sx={{
                  color: 'inherit',
                  '& .MuiSvgIcon-root': {
                    color: 'inherit'
                  },
                  '& .MuiStack-root > .MuiTypography-root': {
                    display: {
                      xs: 'none',
                      sm: 'block'
                    }
                  }
                }}
              >
                {[...(locales ?? [])].sort().map((lang: string) => (
                  // @ts-expect-error
                  <MenuItem
                    component={Link}
                    href={{ pathname, query }}
                    locale={lang}
                    selected={currentLocale === lang}
                    key={lang}
                    defaultValue={lang}
                    value={lang}
                  >
                    <Stack
                      direction="row"
                      alignItems="center"
                      justifyContent="center"
                    >
                      <Avatar
                        sx={{
                          width: '24px',
                          height: '24px',
                          marginRight: '5px'
                        }}
                        src={`/images/flags/${lang}.svg`}
                      />
                      <Typography>
                        {lang === 'en' ? 'English' : 'German'}
                      </Typography>
                    </Stack>
                  </MenuItem>
                ))}
              </Select>
            </FormControl>
            </Stack>
          <Stack marginLeft={2}>
          <IconButton
              color="inherit"
              onClick={() => {
                setMode()
              }}

            >
              {mode === 'dark' ? <LightModeOutlined /> : <DarkModeOutlined />}
            </IconButton>
            </Stack>
        </Toolbar>
      </AppBar>

      <Grid container spacing={2} columns={10} justifyContent="center" alignItems="center" marginTop={2}>
        <Grid item xs={6}>
          <Item><h1>Projektinfo mit Atomgrafik</h1>{info}<br/>{info}<br/>{info}<br/>{info}<br/></Item>
        </Grid>
      </Grid>

      <Grid container spacing={2} columns={20} justifyContent="center" alignItems="center" marginTop={2}>
        <Grid item xs={6}>
          <Item><h2>Beispiel Use Case 1</h2>{info}<br/>{info}<br/></Item>
        </Grid>
        <Grid item xs={6}>
          <Item><h2>Beispiel Use Case 2</h2>{info}<br/>{info}<br/></Item>
        </Grid>
      </Grid>
    </Box>
  )
}

Index.noLayout = true
